Set material pipeline program.

You should call [UpdateMaterialPipelineProgramVariant] after changing a material pipeline program so that the correct variant is selected according to the material states.